import React from 'react';
import HorizontalLine from './HorizontalLine';

const Overview = ({
  propertySize,
  price,
  propertyDimension,
  propertyType,
  developerPostPrice,
  developerRERAno,
  developerPostType
}) => {
  // Function to render price based on availability
  const renderPrice = () => {
    if (price) {
      return `${price}`;
    }
    return `${developerPostPrice}`;
  };

  const renderType = () => {
    if (propertyType) {
      return `${propertyType}`;
    }
    return `${developerPostType}`;
  };


  // Base properties that are always shown
  const baseProps = [
    {
      image: "carbon_area",
      title: "Area",
      val: propertySize
    },
    {
      image: "formkit_rupee",
      title: "Price",
      val: renderPrice()
    }
  ];

  // Conditionally add either Dimension or RERA No
  const dimensionOrRERA = propertyDimension
    ? {
        image: "radix-icons_dimensions",
        title: "Dimension",
        val: propertyDimension
      }
    : {
        image: "number icon in green",
        title: "RERA No",
        val: developerRERAno
      };

  // Add the conditional property and Type to the final props array
  const props = [
    ...baseProps,
    dimensionOrRERA,
    {
      image: "geo_turf-size",
      title: "Type",
      val: renderType()
    }
  ];

  return (
    <div className='bg-white rounded-xl shadow-lg py-4 flex flex-col gap-4'>
      <p className='px-4 sm:px-6 font-semibold text-base sm:text-lg'>
        Basic & Size Details
      </p>
      <HorizontalLine />
      <div className="grid grid-cols-2 md:grid-cols-4 gap-3 sm:gap-4 justify-around px-4 sm:px-6">
        {props.map((prop, index) => (
          <div
            className="flex items-center space-x-2 sm:space-x-4"
            key={index}
          >
            <img
              src={`/icons/${prop.image}.png`}
              alt={prop.title}
              className='w-6 h-6 sm:w-8 sm:h-8'
            />
            <div className='text-xs sm:text-sm'>
              <p className='text-tertiary'>{prop.title}</p>
              <p className='font-medium break-words max-w-[120px] sm:max-w-[150px] md:max-w-full'>
                {prop.val}
              </p>
            </div>
          </div>
        ))}
      </div>
    </div>
  );
};

export default Overview;